from setuptools import setup

setup(name='rdm_distributions',
      version='0.3',
      description='Gaussian and Binomial distributions (basics)',
      packages=['rdm_distributions'],
	  author='Roberto De Monte',
	  author_email='roberto.de.monte5@gmail.com',
      zip_safe=False)
